==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebExporterOptionsBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
/**
 * @hidden
 */
var WebExporterOptionsBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebExporterOptionsBaseDescriptionMetadata, _super);
    function WebExporterOptionsBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebExporterOptionsBaseDescriptionMetadata.b = function (a) {
        if (WebExporterOptionsBaseDescriptionMetadata.a == null) {
            WebExporterOptionsBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebExporterOptionsBaseDescriptionMetadata.c(WebExporterOptionsBaseDescriptionMetadata.a);
        }
        if (a.j(WebExporterOptionsBaseDescriptionMetadata.a)) {
            return;
        }
        a.y(WebExporterOptionsBaseDescriptionMetadata.a);
    };
    WebExporterOptionsBaseDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ExporterOptionsBase");
        a.item("__packageNameWC", "String:grids");
        a.item("IgnoreColumnsVisibility", "Boolean");
        a.item("IgnoreFiltering", "Boolean");
        a.item("IgnoreColumnsOrder", "Boolean");
        a.item("IgnoreSorting", "Boolean");
        a.item("IgnoreGrouping", "Boolean");
        a.item("IgnoreMultiColumnHeaders", "Boolean");
        a.item("FreezeHeaders", "Boolean");
        a.item("AlwaysExportHeaders", "Boolean");
        a.item("FileName", "String");
    };
    WebExporterOptionsBaseDescriptionMetadata.d = function (a) {
        WebExporterOptionsBaseDescriptionMetadata.b(a);
        a.z("WebExporterOptionsBase", WebExporterOptionsBaseDescriptionMetadata.a);
    };
    WebExporterOptionsBaseDescriptionMetadata.$t = markType(WebExporterOptionsBaseDescriptionMetadata, 'WebExporterOptionsBaseDescriptionMetadata');
    WebExporterOptionsBaseDescriptionMetadata.a = null;
    return WebExporterOptionsBaseDescriptionMetadata;
}(Base));
export { WebExporterOptionsBaseDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebExporterOptionsBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
/**
 * @hidden
 */
var WebExporterOptionsBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebExporterOptionsBaseDescriptionMetadata, _super);
    function WebExporterOptionsBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebExporterOptionsBaseDescriptionMetadata.b = function (a) {
        if (WebExporterOptionsBaseDescriptionMetadata.a == null) {
            WebExporterOptionsBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebExporterOptionsBaseDescriptionMetadata.c(WebExporterOptionsBaseDescriptionMetadata.a);
        }
        if (a.k(WebExporterOptionsBaseDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebExporterOptionsBaseDescriptionMetadata.a);
    };
    WebExporterOptionsBaseDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ExporterOptionsBase");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__skipSuffix", "Boolean");
        a.item("IgnoreColumnsVisibility", "Boolean");
        a.item("IgnoreFiltering", "Boolean");
        a.item("IgnoreColumnsOrder", "Boolean");
        a.item("IgnoreSorting", "Boolean");
        a.item("IgnoreGrouping", "Boolean");
        a.item("IgnoreMultiColumnHeaders", "Boolean");
        a.item("ExportSummaries", "Boolean");
        a.item("FreezeHeaders", "Boolean");
        a.item("AlwaysExportHeaders", "Boolean");
        a.item("FileName", "String");
    };
    WebExporterOptionsBaseDescriptionMetadata.d = function (a) {
        WebExporterOptionsBaseDescriptionMetadata.b(a);
        a.ab("WebExporterOptionsBase", WebExporterOptionsBaseDescriptionMetadata.a);
    };
    WebExporterOptionsBaseDescriptionMetadata.$t = markType(WebExporterOptionsBaseDescriptionMetadata, 'WebExporterOptionsBaseDescriptionMetadata');
    WebExporterOptionsBaseDescriptionMetadata.a = null;
    return WebExporterOptionsBaseDescriptionMetadata;
}(Base));
export { WebExporterOptionsBaseDescriptionMetadata };
